policy ändringar/nya möjligheter:
I och med version 2.1.6 har gradm2 ändrat policyfilen och dess
möjligheter en del. Det finns också en ny binär kallad
gradm_pam. Vänligen se README-filen och exempelpolicyn för mer
detaljer.
